Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(635)

Unified Diff: runtime/vm/cpu_x64.cc

Issue 9316071: Dart_PropagateError, take 2. (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 8 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/vm/cpu_ia32.cc ('k') | runtime/vm/dart.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/cpu_x64.cc
===================================================================
--- runtime/vm/cpu_x64.cc (revision 3862)
+++ runtime/vm/cpu_x64.cc (working copy)
@@ -64,16 +64,16 @@
}
-void CPU::JumpToUnhandledExceptionHandler(
+void CPU::JumpToErrorHandler(
uword program_counter,
uword stack_pointer,
uword frame_pointer,
- const UnhandledException& unhandled_exception_object) {
+ const Error& error) {
// The no_gc StackResource is unwound through the tear down of
// stack resources below.
NoGCScope no_gc;
- ASSERT(!unhandled_exception_object.IsNull());
- RawUnhandledException* unhandled_exception = unhandled_exception_object.raw();
+ ASSERT(!error.IsNull());
+ RawError* raw_error = error.raw();
// Prepare for unwinding frames by destroying all the stack resources
// in the previous frames.
@@ -83,12 +83,12 @@
isolate->top_resource()->~StackResource();
}
// Set up the unhandled exception object as the return value in RAX
// and continue from the invocation stub.
#if defined(TARGET_OS_WINDOWS)
UNIMPLEMENTED();
#else
- asm volatile("mov %[unhandled_exception], %%rax;"
+ asm volatile("mov %[raw_error], %%rax;"
"mov %[pc], %%rbx;"
"mov %[fp], %%rcx;"
"mov %[sp], %%rdi;"
@@ -96,7 +96,7 @@
"mov %%rdi, %%rsp;"
"jmp *%%rbx;"
:
- : [unhandled_exception] "m" (unhandled_exception),
+ : [raw_error] "m" (raw_error),
[pc] "m" (program_counter),
[sp] "m" (stack_pointer),
[fp] "m" (frame_pointer));
@@ -83,12 +83,12 @@
isolate->top_resource()->~StackResource();
}
- // Set up the unhandled exception object as the return value in RAX
- // and continue from the invocation stub.
+ // Set up the error object as the return value in RAX and continue
+ // from the invocation stub.
#if defined(TARGET_OS_WINDOWS)
UNIMPLEMENTED();
« no previous file with comments | « runtime/vm/cpu_ia32.cc ('k') | runtime/vm/dart.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698